@@ -1,9 +1,9 @@
 use super::Cipher;
+use crate::error::Result;
 use crate::{error::Error, key_derivation::*, protection_profile::*};
 use util::marshal::*;
 
 use aes::cipher::generic_array::GenericArray;
-use anyhow::Result;
 use byteorder::{BigEndian, ByteOrder, WriteBytesExt};
 use bytes::{BufMut, Bytes, BytesMut};
 use ctr::cipher::{NewCipher, StreamCipher, StreamCipherSeek};
@@ -77,8 +77,10 @@ impl CipherAesCmHmacSha1 {
             auth_key_len,
         )?;
 
-        let srtp_session_auth = HmacSha1::new_from_slice(&srtp_session_auth_tag)?;
-        let srtcp_session_auth = HmacSha1::new_from_slice(&srtcp_session_auth_tag)?;
+        let srtp_session_auth = HmacSha1::new_from_slice(&srtp_session_auth_tag)
+            .map_err(|e| Error::Other(e.to_string()))?;
+        let srtcp_session_auth = HmacSha1::new_from_slice(&srtcp_session_auth_tag)
+            .map_err(|e| Error::Other(e.to_string()))?;
 
         Ok(CipherAesCmHmacSha1 {
             srtp_session_key,
@@ -205,7 +207,7 @@ impl Cipher for CipherAesCmHmacSha1 {
         roc: u32,
     ) -> Result<Bytes> {
         if encrypted.len() < self.auth_tag_len() {
-            return Err(Error::SrtpTooSmall(encrypted.len(), self.auth_tag_len()).into());
+            return Err(Error::SrtpTooSmall(encrypted.len(), self.auth_tag_len()));
         }
 
         let mut writer = BytesMut::with_capacity(encrypted.len() - self.auth_tag_len());
@@ -220,7 +222,7 @@ impl Cipher for CipherAesCmHmacSha1 {
         // See if the auth tag actually matches.
         // We use a constant time comparison to prevent timing attacks.
         if actual_tag.ct_eq(&expected_tag).unwrap_u8() != 1 {
-            return Err(Error::RtpFailedToVerifyAuthTag.into());
+            return Err(Error::RtpFailedToVerifyAuthTag);
         }
 
         // Write cipher_text to the destination buffer.
@@ -282,8 +284,7 @@ impl Cipher for CipherAesCmHmacSha1 {
             return Err(Error::SrtcpTooSmall(
                 encrypted.len(),
                 self.auth_tag_len() + SRTCP_INDEX_SIZE,
-            )
-            .into());
+            ));
         }
 
         let tail_offset = encrypted.len() - (self.auth_tag_len() + SRTCP_INDEX_SIZE);
@@ -307,7 +308,7 @@ impl Cipher for CipherAesCmHmacSha1 {
         // See if the auth tag actually matches.
         // We use a constant time comparison to prevent timing attacks.
         if actual_tag.ct_eq(&expected_tag).unwrap_u8() != 1 {
-            return Err(Error::RtcpFailedToVerifyAuthTag.into());
+            return Err(Error::RtcpFailedToVerifyAuthTag);
         }
 
         let counter = generate_counter(
