@@ -1,9 +1,10 @@
 pub mod cipher_aead_aes_gcm;
 pub mod cipher_aes_cm_hmac_sha1;
 
-use anyhow::Result;
 use bytes::Bytes;
 
+use crate::error::Result;
+
 ///NOTE: Auth tag and AEAD auth tag are placed at the different position in SRTCP
 ///
 ///In non-AEAD cipher, the authentication tag is placed *after* the ESRTCP word
